#!/bin/sh
#----------------------------------------------------------------------------
# /tmp/install.sh - mutt installation
#
# Copyright (c) 2005--2007 Alexander Dahl <post@lespocky.de>
#
# Creation:     2005-08-09  alex
# Last Update:  $Id: install.sh 333 2007-06-22 20:13:17Z alex $
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#----------------------------------------------------------------------------
PACKAGE='mutt'
VERSION='0.1.4'

### defining help functions
function check_overwrite ()
{
    ### $1 should contain destination, $2 source file
    destfile=$1
    srcfile=$2
    if [ -f $destfile ]
    then
        sumdf=`/usr/bin/sha1sum $destfile | /usr/bin/cut -d' ' -f1`
        sumsf=`/usr/bin/sha1sum $srcfile | /usr/bin/cut -d' ' -f1`
        if [ "$sumdf" = "$sumsf" ]
        then
            # file didn't change
            mecho -std "File ${destfile} didn't change..."
            /bin/rm -f $srcfile
        else
            mecho -warn "${destfile} already exists and is different to the "
            mecho -warn "one delivered with this package. You'll be shown a diff "
            mecho -warn "using less and then be asked whether to overwrite or not!"
            anykey
            # show diff and then ask
            /usr/bin/diff -u $destfile $srcfile | less
            answer=`/var/install/bin/ask "Overwrite ${destfile}?"`
            if [ "$answer" = "yes" ]
            then
                /bin/mv -f $srcfile $destfile
                mecho -std "File ${destfile} updated..."
            else
                mecho -warn "Your ${destfile} was not changed. You find the new "
                mecho -warn "one in ${srcfile}."
            fi
        fi
    else
        mecho -std "Copying new ${destfile} from ${srcfile} ..."
        /bin/mv $srcfile $destfile
    fi    
}

### include eislib, this is possible, cause preinstall checks for base 1.2.0
. /var/install/include/eislib
mecho -info "Installing $PACKAGE ${VERSION}..."

mecho -std "Setting file permissions..."
/bin/chmod 0755 /usr/bin/mutt

mecho -std "Copying global configs..."
# first /etc/mime.types
check_overwrite /etc/mime.types /usr/share/doc/mutt/mime.types.dist
check_overwrite /etc/Muttrc /usr/share/doc/mutt/Muttrc.dist

exit 0
